/***[f*****************************************************************
 *      ciwin.h -- Component Interface for PageMaker Windows.
 *
 *      Copyright 1996 (c) Adobe Systems, Inc. All Rights Reserved
 *
 *      Public version
 *
 * $Revision:   1.8  $
 *
 *
 * 
 ***f]*****************************************************************/

#ifndef __CIWIN_H
#define __CIWIN_H

#include "pmtypes.h"

#if defined(MACINTOSH)
typedef PMBool (*MACPROC)(EventRecord *);
#endif
#ifdef __cplusplus
// menu states for AddToMenu
#define kAdnLayoutState		0x0004		// enable in layout mode
#define kAdnStoryEditState	0x0008		// enable in story editor
#define kAdnNoPubState		0x0010		// enable in no pub state

// class to define PageMaker window style
class CIPMWinStyle : public CIInterface
{
public:
	virtual void SetBorderState(PMBool bBorder)=0;
	virtual void SetVisibilityState(PMBool bIsVisible)=0;
	virtual void SetTitleBarState(PMBool bHasTitleBar)=0;
	virtual void SetParentState(PMBool bIsParent)=0;
	virtual void SetChildState(PMBool bIsChild)=0;
	virtual void SetZoomState(PMBool bHasZoomBox)=0;
	virtual void SetSizeState(PMBool bIsSizeable)=0;
	virtual void SetCloseState(PMBool bHasCloseBox)=0;
	virtual void SetMaximizeState(PMBool bIsMaximized)=0;
	virtual void SetStayOnTopState(PMBool bIsStayOnTop)=0;
	virtual void SetModalState(PMBool bIsModal)=0;
	virtual void SetDefaultWindowState(PMBool bIsDefaultWindow)=0;
};

// class to create and destroy PageMaker window
class CIPMWindow : public CIInterface
{
public:
	virtual PMBool Create(CIPMWinStyle *pPlugInWinStyle, void *thePrivateWinData)=0;
	virtual PMBool Destroy()=0;
	virtual void SetPrivateWinData(void *thePrivateWinData)=0;
	virtual void *GetPrivateWinData()=0;
	virtual void SetTitle(char *title)=0;
#if defined (WINDOWS)
	virtual HWND GetWindowHandle()=0;
	virtual void GetSizeLimit(RECT *rect)=0;
	virtual void SetSizeLimit(RECT rect)=0;
#endif
#if defined(MACINTOSH)
	virtual GrafPtr GetWindowHandle()=0;
	virtual void GetSizeLimit(Rect *rect)=0;
	virtual void SetSizeLimit(Rect rect)=0;
#endif
	// menuState is kAdnLayoutState, kAdnStoryEditState, kAdnNoPubState
	virtual PMErr AddToMenu(char *pShowMenuString, char *pHideMenuString,
			WORD menuState=kAdnLayoutState|kAdnNoPubState)=0;
	virtual PMErr DeleteFromMenu(char *pShowMenuString, char *pHideMenuString)=0;
	virtual void Show()=0;
	virtual void Hide()=0;
	virtual PMBool IsVisible()=0;
};

#endif
#endif
