/*
 *--- PageMakerErrors.h ------------------------------------------------
 * Copyright 1986-95 Adobe Systems, Inc.  All rights reserved.
 *
 * Abstract:
 *
 * This file contains all the core defined error constants and error
 * reporting macros.  Refer to the specific PageMaker<xxx>Errs.h
 * file for specific classes of error codes.
 *
 * Each class of errors has two parts:  
 *		1.  expected, or "user" (?E_BASE + numbers);
 *		2.  unexpected, "programmer" errors (?E_NBASE + numbers).
 *----------------------------------------------------------------------
 */

#ifndef __PageMakerErrors__
#define __PageMakerErrors__

#define PM_ERR_BASE 	5000

#define FE_BASE_OLD		(PM_ERR_BASE+0)			// Pre 4.0 File System errors ...
#define FE_NBASE_OLD	(PM_ERR_BASE+100)		// ... DO NOT USE!!!

#define DE_BASE			(PM_ERR_BASE+200)		// Dialog errors ... 
#define DE_NBASE		(PM_ERR_BASE+290)
#define IE_BASE			(PM_ERR_BASE+300)		// Import errors ...
#define IE_NBASE		(PM_ERR_BASE+380)
#define TE_BASE			(PM_ERR_BASE+400)		// Text errors ...
#define TE_NBASE		(PM_ERR_BASE+500)
#define GE_BASE			(PM_ERR_BASE+600)		// Graphics errors ...
#define GE_NBASE		(PM_ERR_BASE+700)
#define PE_BASE			(PM_ERR_BASE+800)		// Printer errors ...
#define PE_NBASE		(PM_ERR_BASE+900)
#define CE_BASE			(PM_ERR_BASE+1000)  	// Clipboard errors ...
#define CE_NBASE		(PM_ERR_BASE+1100)
#define XE_BASE			(PM_ERR_BASE+1200)  	// Export errors ...
#define XE_NBASE		(PM_ERR_BASE+1300)
#define VE_BASE			(PM_ERR_BASE+1400)  	// VDM errors ...
#define VE_NBASE		(PM_ERR_BASE+1500)
#define FE_BASE			(PM_ERR_BASE+1600)  	// File errors (not File System --
#define FE_NBASE		(PM_ERR_BASE+1680)  	//	those errors are in fserr.h)
#define LE_BASE			(PM_ERR_BASE+1800)  	// Link Management errors
#define LE_NBASE		(PM_ERR_BASE+1900)
#define NCPE_BASE		(PM_ERR_BASE+2000)  	// Network copy protection errors
#define NCPE_NBASE  	(PM_ERR_BASE+2100)
#define CQ_ER_BASE  	(PM_ERR_BASE+2200)		// Command/Query errors.

//--- Action code ranges --------------------------------------------

#define PM_AC_BASE 		7500

#define FA_BASE			(PM_AC_BASE+0)			// File actions.
#define EA_BASE			(PM_AC_BASE+100)		// Editor actions.
#define TA_BASE			(PM_AC_BASE+200)		// Text actions.
#define PA_BASE			(PM_AC_BASE+300)		// Printer actions.
#define GA_BASE			(PM_AC_BASE+400)		// Graphics action.
#define DA_BASE			(PM_AC_BASE+500)		// Dialog actions.
#define IA_BASE			(PM_AC_BASE+600)		// Import actions.
#define CA_BASE			(PM_AC_BASE+700)		// Clipboard actions.
#define XA_BASE			(PM_AC_BASE+800)		// Export actions.
#define LA_BASE			(PM_AC_BASE+900)		// Link Management actions.

#define CQ_AC_BASE  	(PM_AC_BASE+1000)		// for CQ action bases.

#endif

// end of PageMakerErrors.h

