/**[f******************************************************************
 *      PMEvent.h -- Header file for PageMaker event
 *
 *      Copyright (c) 1996 Adobe Systems, Inc. All Rights Reserved
 *
 *      
 * ABSTRACT: Header file for PageMaker event. 
 *
 * USAGE: Event notification
 *
 *
 *
 **f]******************************************************************/
#ifndef __PMEVENT_H
#define __PMEVENT_H

#include "CIWindow.h"

#define PMEventID       unsigned long

typedef struct _PMEvent 
{
	//      EventID, see the definition below.
	PMEventID       eventID;
	PMBool            wasHandled;     // Event has been handled by other
							// Plugins.
	//      This is intend to be a pointer to a event dependent structure.
	//      But it is not necessary to be a pointer. 
	void *          lParm;
} PMEvent, *LPPMEvent;

#ifdef __cplusplus
// MAC ONLY INFORMATION
// helper information to the raw EventRecord for MAC
typedef enum 
{
	eResize = 1,                    // this message is received after PM has resized the window
	eActivate = 2,                  // activation 
	eDeactivate = 3,                // deactivation
	eMove = 4,                      // move window
	eClose = 5,                             // close window
	eMenuCmd = 6,                   // menu command
	eMenuHit = 7,                   // menu hit message
	eMouseMove = 8,                 // mouse move
	eMouseDrag = 9,                 // mouse drag
	eLButtonDn = 10,                // left button down
	eRButtonDn = 11,                // right button down
	eLButtonUp = 12,                // left button up
	eLButtonDblClk = 13,    // left button double click
	eLButtonTrpClk = 14,    // left button triple click
	eHScroll = 15,                  // horizontal scroll
	eVScroll = 16,                  // vertical scroll
	eControlCmd = 17,               // message from control (button, listbox, etc.)
	eKeyCmd = 18,                   // key command
	ePaint = 19,                    // paint
	eShow = 20,                     // palette about to be shown
	eHide = 21,                     // palette just hidden
	ePassback = 22                  // none of the above
} PMSysEventID;                 
// END MAC ONLY INFORMATION

typedef struct _PMSysEvent
{
	CIPMWindow *thePMWindow;

#if defined(WINDOWS)
	HWND    hWnd;
	UINT    message;
	WPARAM  wParam;
	LPARAM  lParam;
#endif
#if defined(MACINTOSH)
	EventRecord *pEvent;
#endif
	PMBool wasHandled;                // return TRUE if plugin handled the event and want PageMaker
	PMSysEventID sysEventID;// helper information on what really happen
							// to stop processing the event.
} PMSysEvent, *LPPMSysEvent;

#endif

//      PageMaker EventID
//
//      Important: If you add new event, please also update the TOTAL_EVENT
//      too. The convention for PMEventID is PMEVT_s1_s2_s3
//      where   s1 is the functional area, print for example. 
//                      s2, s3 will be whatever that event can be. 

enum PM_EVENT_ID
{
	PMEVT_APP=0,
	PMEVT_APP_IDLETIMER,                            // timer
	PMEVT_MENUCOMMAND_BEFORE,
	PMEVT_COLOR_AFTER,								// color changed via color palette            
	PMEVT_NEWPUB_AFTER,
	PMEVT_OPENPUB_BEFORE,
	PMEVT_OPENPUB_AFTER,
	PMEVT_CLOSEPUB_BEFORE,
	PMEVT_CLOSEPUB_AFTER,
	PMEVT_SAVEAS_BEFORE,
	PMEVT_SAVE_AFTER,
	PMEVT_REVERTPUB_BEFORE,
	PMEVT_REVERTPUB_AFTER,
	PMEVT_REVERTPAGE_BEFORE,
	PMEVT_REVERTPAGE_AFTER,
	PMEVT_PLACE_BEFORE,
	PMEVT_EXPORT_BEFORE,
	PMEVT_EXPORT_AFTER,
	PMEVT_UNLINK_BEFORE,
	PMEVT_UNLINK_AFTER,
	PMEVT_RELINK_BEFORE,
	PMEVT_RELINK_AFTER,
	PMEVT_DOCUMENTSETUP_AFTER,
	PMEVT_PREFERENCES_AFTER,
	PMEVT_UNDO_OR_REDO_AFTER,
	PMEVT_CUT_AFTER,
	PMEVT_COPY_AFTER,
	PMEVT_PASTE_AFTER,
	PMEVT_MULTIPLEPASTE_BEFORE,
	PMEVT_MULTIPLEPASTE_AFTER,
	PMEVT_SELECTALL_AFTER,
	PMEVT_BOOK_AFTER,
	PMEVT_INDEX_AFTER,
	PMEVT_CREATEINDEX_AFTER,
	PMEVT_CREATETOC_AFTER,
	PMEVT_TRAPPINGOPTION_BEFORE,
	PMEVT_TRAPPINGOPTION_AFTER,
	PMEVT_VIEW_AFTER,
	PMEVT_COLUMNGUIDE_AFTER,
	PMEVT_RULERGUIDE_AFTER,
	PMEVT_GUIDES_RULES_AFTER,
	PMEVT_GOTOPAGE_BEFORE,
	PMEVT_GOTOPAGE_AFTER,
	PMEVT_INSERTPAGES_BEFORE,
	PMEVT_INSERTPAGES_AFTER,
	PMEVT_REMOVEPAGES_BEFORE,
	PMEVT_REMOVEPAGES_AFTER,
	PMEVT_DISPLAYMASTERITEMS_AFTER,
	PMEVT_DISPLAYNONPRINT_AFTER,
	PMEVT_AUTOFLOW_AFTER,
	PMEVT_LAYOUTADJUSTMENT_AFTER,
	PMEVT_TYPESPEC_AFTER,
	PMEVT_PARASPEC_AFTER,
	PMEVT_INDENTTAB_AFTER,
	PMEVT_HYPENATION_AFTER,
	PMEVT_ALIGNMENT_AFTER,
	PMEVT_STYLE_AFTER,
	PMEVT_DEFINESTYLE_AFTER,
	PMEVT_EDITSTYLE_AFTER,
	PMEVT_LINE_AFTER,
	PMEVT_FILL_AFTER,
	PMEVT_LINEFILL_AFTER,
	PMEVT_POLYGONSETTING_AFTER,
	PMEVT_ROUNDCORNER_AFTER,
	PMEVT_CMSPROFILE_AFTER,
	PMEVT_MASK_AFTER,
	PMEVT_TEXTWRAP_AFTER,
	PMEVT_NON_PRINT_AFTER,
	PMEVT_LINKOPTION_AFTER,
	PMEVT_DEFINECOLOR_AFTER,
	PMEVT_EDITCOLOR_AFTER,
	PMEVT_SAVEGRAPHIC_BEFORE,
	PMEVT_SAVEGRAPHIC_AFTER,
	PMEVT_FRONTBACK_AFTER,
	PMEVT_GROUP_AFTER,
	PMEVT_LOCK_AFTER,
	PMEVT_REMOVETRANSFORM_AFTER,
	
	PMEVT_RESIZEOBJECT_BEFORE,
	PMEVT_RESIZEOBJECT_AFTER,
	PMEVT_MOVEOBJECT_BEFORE,
	PMEVT_MOVEOBJECT_AFTER,
	PMEVT_LAYOUT_DRAWOBJECT_BEFORE,
	PMEVT_DRAWOBJECT_AFTER,
	PMEVT_TRANSFORMOBJECT_BEFORE,
	PMEVT_TRANSFORMOBJECT_AFTER,
	PMEVT_CROPOBJECT_BEFORE,
	PMEVT_CROPOBJECT_AFTER,
	PMEVT_CREATEOBJECT_AFTER,
	PMEVT_DELETEOBJECT_BEFORE,
	PMEVT_SELECTOBJECT_AFTER,                               
	PMEVT_DESELECTOBJECT_BEFORE,
	PMEVT_OBJECT_DBLCLICK_BEFORE,                   // double click on object with pointer tool                   
	PMEVT_HLINK_CLICK_BEFORE,						// clicked on hyperlink
	
	PMEVT_RESIZE_APPWINDOW_AFTER,                   
	PMEVT_ACTIVATE_APPWINDOW_AFTER,                
	PMEVT_DEACTIVATE_APPWINDOW_BEFORE,             
	
	PMEVT_RESIZE_LAYOUTWINDOW_AFTER,                
	PMEVT_ACTIVATE_LAYOUTWINDOW_AFTER,            
	PMEVT_DEACTIVATE_LAYOUTWINDOW_BEFORE,   

	PMEVT_RESIZE_STORYEDITWINDOW_AFTER,                
	PMEVT_ACTIVATE_STORYEDITWINDOW_AFTER,            
	PMEVT_DEACTIVATE_STORYEDITWINDOW_BEFORE,   

	PMEVT_PRINT_BEFORE,
	PMEVT_PRINT_DSCHEADER_AFTER,                    // before PageMaker finishes up DSC header (PostScript only)
	PMEVT_PRINT_PROLOG_BEFORE,                              // before download PostScript prolog (PostScript only
	PMEVT_PRINT_PROLOG_AFTER,                               // after download PostScript prolog (PostScript only
	PMEVT_PRINT_DOCSETUP_BEFORE,                    // before print job setup
	PMEVT_PRINT_DOCSETUP_AFTER,                             // after print job setup
	PMEVT_PRINT_DSCCOMMENT_PAGELEVEL,               // page level DSC comments (PostScript only)
	PMEVT_PRINT_PAGESETUP_BEFORE,                   // before page setup
	PMEVT_PRINT_PAGESETUP_AFTER,                    // after page setup
	PMEVT_PRINT_OBJECT_BEFORE,                              // before each object
	PMEVT_PRINT_OBJECT_AFTER,                               // after each object
	PMEVT_PRINT_PAGETRAILER_BEFORE,                 // before page trailer (PostScript only)
	PMEVT_PRINT_PAGETRAILER_AFTER,                  // after page trailer (PostScript only)
	PMEVT_PRINT_PRMARKS_BEFORE,                             // before printer marks (PostScript only)
	PMEVT_PRINT_PRMARKS_AFTER,                              // after printer marks (PostScript only)
	PMEVT_PRINT_JOBTRAILER_BEFORE,                  // before print job trailer (PostScript only)
	PMEVT_PRINT_JOBTRAILER_AFTER,                   // after print job trailer (PostScript only)

	PMEVT_HYPHENATE_WORD,                                   // before PageMaker hyphenate a word

	PMEVT_TEXTSTORY_ENTER_AFTER,                    // after entering a text story during text tool 
	PMEVT_TEXT_SELECT_AFTER,                                // after text selection/text caret  during text tool
	PMEVT_TEXT_ENTER_AFTER,                                 // after entering text during text tool
	PMEVT_TEXT_DELETE_AFTER,                                // after deleting text during text tool
	PMEVT_OBJEDIT_MEDIA_IMAGE,						// when double-clicking image when image has pluginType non-null.
	PMEVT_APP_STARTUP_AFTER,					// after PageMaker is initialized (during startup)
	PMEVT_TEXT_DELETE_BEFORE,                               // before deleting text during text tool
	PMEVT_PLUGIN_COMMAND_BEFORE,					// before processing a plugin command
	PMEVT_PLUGIN_COMMAND_AFTER,						// after processing a plugin command
	PMEVT_APP_SHUTDOWN,								// PageMaker is shutting down

	PMEVT_SE_TEXT_SELECT_AFTER,                             // after text selection/text caret during story editor
	PMEVT_SE_TEXT_ENTER_AFTER,                              // after entering text during story editor
	PMEVT_SE_TEXT_DELETE_AFTER,                             // after deleting text during story editor
	PMEVT_SE_TEXT_DELETE_BEFORE,                            // before deleting text during story editor

	PMEVT_PLUGINS_STARTUP_AFTER,							// after PageMaker has initialized plugins (during startup, changeenv)
	PMEVT_PLUGINS_SHUTDOWN,									// before PageMaker shuts down plugins (before quit, changeenv)
	
	PMEVT_DELETESTYLE_AFTER,
	PMEVT_DELETECOLOR_AFTER,

	PMEVT_SAVE_BEFORE,								// before a named-pub is saved.

	PMEVT_PAGEADJUST_AFTER,							// after each page spread adjustment
	PMEVT_DOCADJUST_AFTER,							// after the document adjustment

	PMEVT_EVENT_END
};

#define TOTAL_EVENTS                                    PMEVT_EVENT_END
#endif


